Correlation pattern recognizer (Copatrec) package.
For more information, please see the example and Document notebook.

# How to use Copatrec
To use Copatrec, it should be either cloned from the GitHub, or
installed using the package files (pip and py providers will
be ready in future)

## Recommend installation
It is recommended to install copatrec using pip.

## Installing using pip
To install copatrec, please use the following code in your terminals.

### Linux, conda, or python environment with access to pip
pip install copatrec


## Cloning (copying) source code:
The source code has a hierarchic structure to be able to create package files. 
Thus, the source code can be found in 'src' folder. 
Also, examples can be found in 'example' folder.

### Required packages to use Copatrec
If the package is imported from GitHub, then it would be suggested
to install following packages (dependencies) in your system using pip or any other 
preferred approaches. 
- matplotlib
- numpy
- pandas
- scipy
- sklearn

# Examples

## JSS.py
An example file with setups to reproducing paper results for the Journal of Statistical Software.

## Tutorial files
There are two files in different formats (.py and .ipynb). For a detailed tutorial of Copatrec, the Jupyter
file (Document.ipynb) is recommended. 